@@ -34,7 +34,7 @@
 #define _GLIBCXX_RELEASE 11
 
 // The datestamp of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20220421
+#define __GLIBCXX__ 20230528
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -1092,6 +1092,9 @@ namespace std
 /* Define if readlink is available in <unistd.h>. */
 #define _GLIBCXX_HAVE_READLINK 1
 
+/* Define to 1 if you have the `secure_getenv' function. */
+#define _GLIBCXX_HAVE_SECURE_GETENV 1
+
 /* Define to 1 if you have the `setenv' function. */
 #define _GLIBCXX_HAVE_SETENV 1
 
